==> ws-addressing-definition-0.9.0-sources.jar: com/ebmwebsourcing/wsstar/addressing/definition/impl/WSAddressingWriterImpl.java <==
/**
 * easySchema - easyWSDL toolbox Platform.
 * Copyright (c) 2008,  eBM Websourcing
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the University of California, Berkeley nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.ebmwebsourcing.wsstar.addressing.definition.impl;

import java.io.StringWriter;
import java.util.List;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.JAXBException;
import javax.xml.namespace.QName;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;

import org.apache.commons.lang.NotImplementedException;
import org.ow2.easywsdl.schema.api.abstractElmt.AbstractSchemaElementImpl;
import org.w3c.dom.Document;

import com.ebmwebsourcing.wsstar.addressing.definition.api.EndpointReferenceType;
import com.ebmwebsourcing.wsstar.addressing.definition.api.WSAddressingException;
import com.ebmwebsourcing.wsstar.addressing.definition.api.WSAddressingWriter;


/**
 * @author Nicolas Salatge - eBM WebSourcing
 */
public class WSAddressingWriterImpl extends WSAddressingJAXBContext implements
        WSAddressingWriter {



	public WSAddressingWriterImpl() throws WSAddressingException {
		try {
			WSAddressingJAXBContext.createDefaultContext();
		} catch (final WSAddressingException e) {
			throw new WSAddressingException(e);
		}
	}

	public WSAddressingWriterImpl(List<Class> addedObjectFactories)
	throws WSAddressingException {
		try {
			WSAddressingJAXBContext.createContextWithOtherObjectFactories(addedObjectFactories);
		} catch (final WSAddressingException e) {
			throw new WSAddressingException(e);
		}
	}

    @SuppressWarnings("unchecked")
    private static Document convertEndpointReferenceType2DOMElement(final QName tagName,
            final com.ebmwebsourcing.wsstar.addressing.definition.org.w3._2005._08.addressing.EndpointReferenceType def)
            throws WSAddressingException {
        Document doc = null;
        try {
            doc = DocumentBuilderFactory.newInstance().newDocumentBuilder().newDocument();

            // TODO : Check if it is a Thread safe method
            final JAXBElement element = new JAXBElement(tagName, def.getClass(), def);

            WSAddressingWriterImpl.getJaxbContext().createMarshaller().marshal(element, doc);
        } catch (final JAXBException ex) {
            throw new WSAddressingException(
                    "Failed to build XML binding from SchemaImpl descriptor Java classes", ex);
        } catch (final ParserConfigurationException ex) {
            throw new WSAddressingException(
                    "Failed to build XML binding from SchemaImpl descriptor Java classes", ex);

        }
        return doc;
    }

    @SuppressWarnings("unchecked")
    private static String convertEndpointReferenceType2String(
            final com.ebmwebsourcing.wsstar.addressing.definition.org.w3._2005._08.addressing.EndpointReferenceType def)
            throws WSAddressingException {

        try {
            final StringWriter stringWriter = new StringWriter();
            // TODO : Check if it is a Thread safe method

            final JAXBElement element = new JAXBElement(new QName(Constants.WSADDRESSING_NAMESPACE,
            		Constants.ENDPOINT_ROOT_TAG), def.getClass(), def);

            WSAddressingWriterImpl.getJaxbContext().createMarshaller().marshal(element, stringWriter);

            return stringWriter.toString();
        } catch (final JAXBException e) {
            throw new WSAddressingException(
                    "Failed to build XML binding from Agreement descriptor Java classes", e);
        }
    }

    public Document getDocument(final EndpointReferenceType def) throws WSAddressingException {
        Document doc = null;
        if ((def != null)
                && (def instanceof EndpointReferenceType)) {
                doc = WSAddressingWriterImpl
                        .convertEndpointReferenceType2DOMElement(def.getTagQName(), (com.ebmwebsourcing.wsstar.addressing.definition.org.w3._2005._08.addressing.EndpointReferenceType) ((AbstractSchemaElementImpl) def)
                                .getModel());
                if(def.getDocumentBaseURI() != null) {
                	doc.setDocumentURI(def.getDocumentBaseURI().getPath());
                }
        }
        return doc;
    }

    public boolean getFeature(final String name) throws IllegalArgumentException {
        throw new NotImplementedException();
    }

    public void setFeature(final String name, final boolean value) throws IllegalArgumentException {
        throw new NotImplementedException();
    }

    public String writeEndpointReferenceType(final EndpointReferenceType def) throws WSAddressingException {
        String res = null;
        if ((def != null)
                && (def instanceof EndpointReferenceType)) {
                res = WSAddressingWriterImpl
                        .convertEndpointReferenceType2String((com.ebmwebsourcing.wsstar.addressing.definition.org.w3._2005._08.addressing.EndpointReferenceType) ((AbstractSchemaElementImpl) def)
                                .getModel());
            
        }
        return res;
    }

}

==> ws-addressing-definition-1.0-sources.jar: com/ebmwebsourcing/wsstar/addressing/definition/impl/WSAddressingWriterImpl.java <==
/**
 * easySchema - easyWSDL toolbox Platform.
 * Copyright (c) 2008,  eBM Websourcing
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the University of California, Berkeley nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.ebmwebsourcing.wsstar.addressing.definition.impl;

import java.io.File;
import java.io.StringWriter;
import java.util.List;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.JAXBException;
import javax.xml.namespace.QName;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.transform.Result;
import javax.xml.transform.Source;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerConfigurationException;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.TransformerFactoryConfigurationError;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;

import org.apache.commons.lang.NotImplementedException;
import org.ow2.easywsdl.schema.api.abstractElmt.AbstractSchemaElementImpl;
import org.w3c.dom.Document;

import com.ebmwebsourcing.wsstar.addressing.definition.api.EndpointReferenceType;
import com.ebmwebsourcing.wsstar.addressing.definition.api.WSAddressingException;
import com.ebmwebsourcing.wsstar.addressing.definition.api.WSAddressingWriter;


/**
 * @author Nicolas Salatge - eBM WebSourcing
 */
public class WSAddressingWriterImpl extends WSAddressingJAXBContext implements
        WSAddressingWriter {



	public WSAddressingWriterImpl() throws WSAddressingException {
		try {
			WSAddressingJAXBContext.createDefaultContext();
		} catch (final WSAddressingException e) {
			throw new WSAddressingException(e);
		}
	}

	public WSAddressingWriterImpl(List<Class> addedObjectFactories)
	throws WSAddressingException {
		try {
			WSAddressingJAXBContext.createContextWithOtherObjectFactories(addedObjectFactories);
		} catch (final WSAddressingException e) {
			throw new WSAddressingException(e);
		}
	}

    @SuppressWarnings("unchecked")
    private static Document convertEndpointReferenceType2DOMElement(final QName tagName,
            final com.ebmwebsourcing.wsstar.addressing.definition.org.w3._2005._08.addressing.EndpointReferenceType def)
            throws WSAddressingException {
        Document doc = null;
        try {
            doc = DocumentBuilderFactory.newInstance().newDocumentBuilder().newDocument();

            // TODO : Check if it is a Thread safe method
            final JAXBElement element = new JAXBElement(tagName, def.getClass(), def);

            WSAddressingWriterImpl.getJaxbContext().createMarshaller().marshal(element, doc);
        } catch (final JAXBException ex) {
            throw new WSAddressingException(
                    "Failed to build XML binding from SchemaImpl descriptor Java classes", ex);
        } catch (final ParserConfigurationException ex) {
            throw new WSAddressingException(
                    "Failed to build XML binding from SchemaImpl descriptor Java classes", ex);

        }
        return doc;
    }

    @SuppressWarnings("unchecked")
    private static String convertEndpointReferenceType2String(
            final com.ebmwebsourcing.wsstar.addressing.definition.org.w3._2005._08.addressing.EndpointReferenceType def)
            throws WSAddressingException {

        try {
            final StringWriter stringWriter = new StringWriter();
            // TODO : Check if it is a Thread safe method

            final JAXBElement element = new JAXBElement(new QName(Constants.WSADDRESSING_NAMESPACE,
            		Constants.ENDPOINT_ROOT_TAG), def.getClass(), def);

            WSAddressingWriterImpl.getJaxbContext().createMarshaller().marshal(element, stringWriter);

            return stringWriter.toString();
        } catch (final JAXBException e) {
            throw new WSAddressingException(
                    "Failed to build XML binding from Agreement descriptor Java classes", e);
        }
    }

    public Document getDocument(final EndpointReferenceType def) throws WSAddressingException {
        Document doc = null;
        if ((def != null)
                && (def instanceof EndpointReferenceType)) {
                doc = WSAddressingWriterImpl
                        .convertEndpointReferenceType2DOMElement(def.getTagQName(), (com.ebmwebsourcing.wsstar.addressing.definition.org.w3._2005._08.addressing.EndpointReferenceType) ((AbstractSchemaElementImpl) def)
                                .getModel());
                if(def.getDocumentBaseURI() != null) {
                	doc.setDocumentURI(def.getDocumentBaseURI().getPath());
                }
        }
        return doc;
    }

    public boolean getFeature(final String name) throws IllegalArgumentException {
        throw new NotImplementedException();
    }

    public void setFeature(final String name, final boolean value) throws IllegalArgumentException {
        throw new NotImplementedException();
    }

    public String writeEndpointReferenceType(final EndpointReferenceType def) throws WSAddressingException {
        String res = null;
        if ((def != null)
                && (def instanceof EndpointReferenceType)) {
                res = WSAddressingWriterImpl
                        .convertEndpointReferenceType2String((com.ebmwebsourcing.wsstar.addressing.definition.org.w3._2005._08.addressing.EndpointReferenceType) ((AbstractSchemaElementImpl) def)
                                .getModel());
            
        }
        return res;
    }

    /*
     * (non-Javadoc)
     * @see com.ebmwebsourcing.wsstar.addressing.definition.api.WSAddressingWriter#writeEndpointReferenceType(com.ebmwebsourcing.wsstar.addressing.definition.api.EndpointReferenceType, java.io.File)
     */
    public void writeEndpointReferenceType(EndpointReferenceType edpRef, File file) throws WSAddressingException {
    	Document edpRefAsDoc = this.getDocument(edpRef);
    	this.flushToFile(edpRefAsDoc, file);
    }
    
    /**
     * write a DOM document to a file
     * @param doc the DOM document to write on the file system
     * @param file the file which the DOM document must be write in
     * @throws WSNotificationException
     */
    private void flushToFile(Document doc, File file) throws WSAddressingException {

		try{
			// Prepare the DOM document for writing		    
			Source source = new DOMSource(doc);

			// Prepare the output file		    		
			Result result = new StreamResult(file);

			// Write the DOM document to the file
			Transformer xformer;

			xformer = TransformerFactory.newInstance().newTransformer();
			xformer.transform(source, result);
			
		} catch (TransformerConfigurationException e) {
			throw new WSAddressingException("Problem occurs during \"persistency\" process",e);
		} catch (TransformerFactoryConfigurationError e) {
			throw new WSAddressingException("Problem occurs during \"persistency\" process",e);
		} catch (TransformerException e) {			
			throw new WSAddressingException("Problem occurs during \"persistency\" process",e);
		}
	    
	} 
}
